==> haskell-ixset-typed-0.5.1.0-161-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ixset-typed
version:              0.5.1.0
visibility:           public
id:                   ixset-typed-0.5.1.0-7IBJVDDlGnEECJabT6wWts
key:                  ixset-typed-0.5.1.0-7IBJVDDlGnEECJabT6wWts
license:              BSD-3-Clause
maintainer:           Andres Löh <andres@well-typed.com>
author:               Andres Löh, Happstack team, HAppS LLC
synopsis:             Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.

    Sets can be created, modified, and queried in various ways.

    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.

    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.

category:             Data Structures
abi:                  27fbef86144e595acbf80a26380ed068
exposed:              True
exposed-modules:      Data.IxSet.Typed Data.IxSet.Typed.Ix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ixset-typed-0.5.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ixset-typed-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ixset-typed
hs-libraries:         HSixset-typed-0.5.1.0-7IBJVDDlGnEECJabT6wWts
depends:
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    safecopy-0.10.4.2-Eh83ut3xFHvIS5wK54HQ7G
    syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html:         /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ixset-typed-0.5.1.0-213.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ixset-typed
version:              0.5.1.0
visibility:           public
id:                   ixset-typed-0.5.1.0-9XjffIW6UEL1QHB5EFirRS
key:                  ixset-typed-0.5.1.0-9XjffIW6UEL1QHB5EFirRS
license:              BSD-3-Clause
maintainer:           Andres Löh <andres@well-typed.com>
author:               Andres Löh, Happstack team, HAppS LLC
synopsis:             Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.

    Sets can be created, modified, and queried in various ways.

    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.

    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.

category:             Data Structures
abi:                  2f23c036c9482e06ab450866224ea9a3
exposed:              True
exposed-modules:      Data.IxSet.Typed Data.IxSet.Typed.Ix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ixset-typed-0.5.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ixset-typed-0.5.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ixset-typed-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ixset-typed
hs-libraries:         HSixset-typed-0.5.1.0-9XjffIW6UEL1QHB5EFirRS
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    safecopy-0.10.4.2-2mdiHHIJpfs8egdXSv0OBX
    syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html:         /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
